summaryrefslogtreecommitdiffstats
path: root/amarok/src/metabundle.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'amarok/src/metabundle.cpp')
-rw-r--r--amarok/src/metabundle.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/amarok/src/metabundle.cpp b/amarok/src/metabundle.cpp
index 1159fe20..8ac01799 100644
--- a/amarok/src/metabundle.cpp
+++ b/amarok/src/metabundle.cpp
@@ -1509,7 +1509,7 @@ MetaBundle::save( TagLib::FileRef* fileref )
// QT's version encodeAttr is 1) private to TQDom, and 2) a litte slow. This
// one can be made public if needed. It happens to be on a critical path
// (each char of playlist / undo save). TQStyleSheet::escape does not deal with
// tqunicode chars illegal for XML. There's a lot of junk in those tags
static inline void xmlEncode(TQTextStream &stream, const TQString &str)
{
TQString tmp;
@@ -1517,7 +1517,7 @@ static inline void xmlEncode(TQTextStream &stream, const TQString &str)
uint i = 0;
while ( i < cur->length() )
{
- uint uc = (*cur)[i].tqunicode();
+ uint uc = (*cur)[i].unicode();
// we try to accumulate unescaped chars before writing to stream
const char *escaped;
// careful about the order of tests, common before less common
@@ -1530,7 +1530,7 @@ static inline void xmlEncode(TQTextStream &stream, const TQString &str)
else if ( uc == '"' ) escaped = "&quot;";
else
{
// see if it's a XML-valid tqunicode char at all
if ( (0x20 <= uc && uc <= 0xD7FF || 0xE000 <= uc && uc <= 0xFFFD
|| uc == 0x9 || uc == 0xA || uc == 0xD) )
// fairly common, other ascii chars
@@ -1509,7 +1509,7 @@ MetaBundle::save( TagLib::FileRef* fileref )
// one can be made public if needed. It happens to be on a critical path
// (each char of playlist / undo save). TQStyleSheet::escape does not deal with
-// tqunicode chars illegal for XML. There's a lot of junk in those tags
+// unicode chars illegal for XML. There's a lot of junk in those tags
static inline void xmlEncode(TQTextStream &stream, const TQString &str)
{
@@ -1530,7 +1530,7 @@ static inline void xmlEncode(TQTextStream &stream, const TQString &str)
else
{
- // see if it's a XML-valid tqunicode char at all
+ // see if it's a XML-valid unicode char at all
if ( (0x20 <= uc && uc <= 0xD7FF || 0xE000 <= uc && uc <= 0xFFFD
|| uc == 0x9 || uc == 0xA || uc == 0xD) )